@@ -33,7 +33,7 @@ def get_default_logging_conf(log_level: str, formatter: str, formatter_std_lib:
     if formatter not in formatters or formatter_std_lib not in formatters:
         raise NotImplementedError("formatter not supported")
 
-    configuration = {
+    return {
         'version': 1,
         'disable_existing_loggers': False,
         'formatters': formatters,
@@ -95,5 +95,3 @@ def get_default_logging_conf(log_level: str, formatter: str, formatter_std_lib:
             },
         },
     }
-
-    return configuration
