@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime, timezone
 
 from pythonjsonlogger import jsonlogger
 
@@ -13,7 +13,7 @@ class LogFormatter(jsonlogger.JsonFormatter):
         # add project name
         log_record['microservice'] = payla_utils_settings.MICROSERVICE_NAME
         if not log_record.get('timestamp'):
-            now = datetime.utcnow().strftime('%Y-%m-%dT%H:%M:%S.%fZ')
+            now = datetime.now(tz=timezone.utc).strftime('%Y-%m-%dT%H:%M:%S.%fZ')
             log_record['timestamp'] = now
         if log_record.get('level'):
             log_record['level'] = log_record['level'].upper()
