@@ -1,6 +1,7 @@
+from __future__ import annotations
+
 import logging
 import logging.config
-from typing import Optional
 
 import structlog
 from structlog import contextvars
@@ -20,8 +21,8 @@ class LoggingConfigurator:
         self,
         service_name: str,
         log_level: str,
-        own_apps: Optional[list] = None,
-        config: Optional[dict] = None,
+        own_apps: list | None = None,
+        config: dict | None = None,
         setup_logging_dict: bool = False,
     ):
         self.service_name = service_name
@@ -43,8 +44,8 @@ class LoggingConfigurator:
         return event_dict
 
     def add_open_telemetry_spans(self, _, __, event_dict):
-        from opentelemetry import trace
-        from opentelemetry.trace import format_span_id, format_trace_id
+        from opentelemetry import trace  # noqa: PLC0415
+        from opentelemetry.trace import format_span_id, format_trace_id  # noqa: PLC0415
 
         span = trace.get_current_span()
         if not span.is_recording():
@@ -85,7 +86,7 @@ class LoggingConfigurator:
             processors.insert(3, self.add_open_telemetry_spans)
         return processors
 
-    def _fix_sentry_logging(self, extra_loggers_names: Optional[list[str]] = None):
+    def _fix_sentry_logging(self, extra_loggers_names: list[str] | None = None):
         """
         Ignore loggers using struct log to avoid duplicated events sent to sentry
         """
@@ -98,7 +99,7 @@ class LoggingConfigurator:
         formatter='json_formatter',
         formatter_std_lib='json_formatter',
         tracing_enabled=False,
-        extra_loggers_names: Optional[list[str]] = None,
+        extra_loggers_names: list[str] | None = None,
     ):
         if self.setup_logging_dict:
             logger_init_config = self.config or get_default_logging_conf(
