@@ -1,3 +1,5 @@
+# ruff: noqa: S607
+
 import subprocess
 from io import StringIO
 
@@ -6,6 +8,7 @@ from django.core.management import BaseCommand, call_command
 
 class Command(BaseCommand):
     help = "Make and compile messages for german language"
+    requires_system_checks: list = []
 
     def handle(self, *args, **options):
         self.stdout.write("Making messages", style_func=self.style.SUCCESS)
