@@ -12,7 +12,7 @@ from payla_utils.settings import payla_utils_settings
 
 class Command(BaseCommand):
     """
-    This management command will init environment based on the current env (local.dev, dev, stage, playground and prod)
+    This management command will init environment based on the current env (local.dev, stage, playground and prod)
 
     - load fixtures on the first run (when the DB is empty)
     - setup custom theme for admin_interface
@@ -25,7 +25,7 @@ class Command(BaseCommand):
         parser.add_argument('--env', type=str, default='', help='force which env to use')
 
     def handle(self, *args: Any, **options: Any):
-        env = options.get('env', None) or payla_utils_settings.ENVIRONMENT
+        env = options.get('env') or payla_utils_settings.ENVIRONMENT
         self.setup_theme(env)
         self.setup_initial_fixtures(env=env)
         self.run_extra_commands()
@@ -73,7 +73,7 @@ class Command(BaseCommand):
             custom_command = command.split(' ')
             # handle custom commands with arguments
             if len(custom_command) > 1:
-                command, *args = custom_command
-                call_command(command, *args)
+                new_command, *args = custom_command
+                call_command(new_command, *args)
             else:
                 call_command(command)
