@@ -5,7 +5,7 @@ PAYLA_UTILS = {
     'APP_NAME': 'My App',
     # Used for json logging
     'MICROSERVICE_NAME: 'myapp',
-    # dev, stage, prod ...
+    # stage, playground, prod ...
     'ENVIRONMENT': ENVIRONMENT,
     'INITIAL_FIXTURES': [
         os.path.join(BASE_DIR, 'testapp', 'fixtures', 'users.json'),
@@ -14,6 +14,9 @@ PAYLA_UTILS = {
     'REQUEST_ID_HEADER': 'X-Request-ID',
     'RUN_EXTRA_COMMANDS': ['loadinitialusers', 'setup_something'],
     'LOCAL_DJANGO_ADMIN_PASSWORD': os.environ.get('LOCAL_DJANGO_ADMIN_PASSWORD', 'admin'),
+    'USE_PGTRIGGER': False,
+    'USE_HISTORICAL_MODELS': False,
+    'HISTORICAL_IGNORE_FIELD_NAME': [],
     'ENV_THEMES': {
         'local.dev': {
             'title_color': '#000000',
@@ -31,22 +34,6 @@ PAYLA_UTILS = {
             'css_save_button_background_color': '#6d6d6d',
             'css_save_button_background_hover_color': '#4a4a4a',
         },
-        'dev': {
-            'title_color': '#ffffff',
-            'env_color': '#00cb68',
-            'css_header_background_color': '#007b3b',
-            'css_header_text_color': '#f5dd5d',
-            'css_header_link_color': '#ffffff',
-            'css_header_link_hover_color': '#1e00ac',
-            'css_module_background_color': '#006731',
-            'css_module_background_selected_color': '#ffffff',
-            'css_module_text_color': '#ffffff',
-            'css_module_link_color': '#ffffff',
-            'css_module_link_hover_color': '#5f0000',
-            'css_generic_link_color': '#000000',
-            'css_save_button_background_color': '#006731',
-            'css_save_button_background_hover_color': '#01a74f',
-        },
         'stage': {
             'title_color': '#ffffff',
             'env_color': '#ffcb38',
@@ -103,7 +90,8 @@ This module provides the `payla_utils_setting` object, that is used to access
 Payla Utils settings, checking for user settings first, then falling
 back to the defaults.
 """
-from typing import Optional
+
+from __future__ import annotations
 
 from django.conf import settings
 
@@ -120,6 +108,12 @@ DEFAULTS: dict = {
     'LOCAL_DJANGO_ADMIN_PASSWORD': None,
     'REQUEST_ID_HEADER': None,
     'SERVER_IP': None,
+    'USE_PGTRIGGER': False,
+    'USE_HISTORICAL_MODELS': False,
+    'HISTORICAL_IGNORE_MODELS': [],
+    'HISTORICAL_IGNORE_FIELD_NAME': [],
+    'GROUPS_PERMISSIONS_FILE_PATH': None,
+    'GROUPS_USERS_FILE_PATH': None,
     'ENV_THEMES': {
         'local.dev': {
             'title_color': '#000000',
@@ -137,22 +131,6 @@ DEFAULTS: dict = {
             'css_save_button_background_color': '#6d6d6d',
             'css_save_button_background_hover_color': '#4a4a4a',
         },
-        'dev': {
-            'title_color': '#ffffff',
-            'env_color': '#00cb68',
-            'css_header_background_color': '#007b3b',
-            'css_header_text_color': '#f5dd5d',
-            'css_header_link_color': '#ffffff',
-            'css_header_link_hover_color': '#1e00ac',
-            'css_module_background_color': '#006731',
-            'css_module_background_selected_color': '#ffffff',
-            'css_module_text_color': '#ffffff',
-            'css_module_link_color': '#ffffff',
-            'css_module_link_hover_color': '#5f0000',
-            'css_generic_link_color': '#000000',
-            'css_save_button_background_color': '#006731',
-            'css_save_button_background_hover_color': '#01a74f',
-        },
         'stage': {
             'title_color': '#ffffff',
             'env_color': '#ffcb38',
@@ -207,7 +185,7 @@ DEFAULTS: dict = {
 
 
 class PaylaUtilsSettings:
-    def __init__(self, defaults: Optional[dict] = None) -> None:
+    def __init__(self, defaults: dict | None = None) -> None:
         self.defaults = defaults or DEFAULTS
         self._cached_attrs: set = set()
 
@@ -219,7 +197,7 @@ class PaylaUtilsSettings:
 
     def __getattr__(self, attr):
         if attr not in self.defaults:
-            raise AttributeError("Invalid setting: '%s'" % attr)
+            raise AttributeError(f"Invalid setting: '{attr}'")
 
         try:
             # Check if present in user settings
